@@ -26,7 +26,7 @@ waitForFiles = function(path, fns, timeout = NA_real_) {
 
 waitForResults = function(reg, ids) {
   waitForFiles(
-    file.path(reg$file.dir, "results"),
+    fp(reg$file.dir, "results"),
     sprintf("%i.rds", .findDone(reg, ids)$job.id),
     reg$cluster.functions$fs.latency
   )
